/******************************************************************************

**********************************  ָ   **********************************

*******************************************************************************

--------------------------------------------------------------------------------------

|                    |  BYTE1  |   BYTE2    |    BYTE3   |   BYTE4    |   BYTE5    |   BYTE6    |

|                        | (CODE)  |            |            |            |            |            |

--------------------------------------------------------------------------------------

| Write Enable           |   06h   |            |            |            |            |            |

| д״̬Ĵ       |   50h   |            |            |            |            |            |

| Write Disable          |   04h   |            |            |            |            |            |

| Read Status Register-1 |   05h   | S7CS0     |            |            |            |            |

| Read Status Register-2 |   35h   | S15CS8    |            |            |            |            |

| Write Status Register  |   01h   | S7CS0     | S15-S8     |            |            |            |

| Page Program           |   02h   | A23CA16   | A15CA8    |  A7CA0    |D7CD0      |            |

| Quad Page Program      |   32h   | A23CA16   | A15CA8    |  A7CA0    |D7CD0,..(3)|            |

| Sector Erase (4KB)     |   20h   | A23CA16   | A15CA8    |  A7CA0    |            |            |

| Block Erase (32KB)     |   52h   | A23CA16   | A15CA8    |  A7CA0    |            |            |

| Block Erase (64KB)     |   D8h   | A23CA16   | A15CA8    |  A7CA0    |            |            |

| Chip Erase             | C7h/60h |            |            |            |            |            |

| Erase / Program Suspend|   75h   |            |            |            |            |            |

| Erase / Program Resume |   7Ah   |            |            |            |            |            |

| Power-down             |   B9h   |            |            |            |            |            |

| λģʽ         |   FFh   |    FFh     |            |            |            |            |

--------------------------------------------------------------------------------------

| Read Data              |   03h   |  A23-A16   | A15-A8     |  A7-A0     |  (D7-D0)   |            |

| Fast Read              |   0Bh   |  A23-A16   | A15-A8     |  A7-A0     |  dummy     |(D7-D0)     |

| Fast Read Dual Output  |   3Bh   |  A23-A16   | A15-A8     |  A7-A0     |  dummy     |(D7-D0, ) |

| Fast Read Quad Output  |   6Bh   |  A23-A16   | A15-A8     |  A7-A0     |  dummy     |(D7-D0, ) |

| Fast Read Dual I/O     |   BBh   |  A23-A8(2) | A7-A0,     |  M7-M0(2)  | (D7-D0,..) |            |

| Fast Read Quad I/O     |   EBh   |A23-A0,M7-M0|xxxx,D7-D0,.|(D7-D0,..)  |            |            |

| Word Read Quad I/O     |   E7h   |A23-A0,M7-M0|xx,D7-D0,.  |(D7-D0,..)  |            |            |

|Octal Word Read Quad I/O|   E3h   |A23-A0,M7-M0|(D7-D0,.)   |            |            |            |

| Set Burst with Wrap    |     77h |xxxxxx,W6-W4|            |            |            |            |

--------------------------------------------------------------------------------------

|Release Device ID       |  ABh    | dummy      |  dummy     |  dummy     |  (ID7-ID0) |            |

|ID                      |  90h    | dummy      |  dummy     |  00h       |  (MF7-MF0) | (ID7-ID0)  | 

|ID by Dual I/O          |  92h    | A23-A8     |A7-A0,M[7:0]|MF[7:0],ID[7:0] |        |            |   

|ID  by Quad I/O         |  94h    | A23-A0,M[7:0]| xxxx,(MF[7:0],ID[7:0])|(MF[7:0], ID[7:0], )| ||   

|JEDEC ID                |  9Fh    | (MF7-MF0)  | (ID15-ID8) | (ID7-ID0)  |            |            |

|Read Unique ID          |  4Bh    | dummy      |  dummy     |  dummy     |  dummy     | (ID63-ID0) |

|Erase Security Registers|  44h    | A23CA16   |  A15CA8   |  A7CA0    |            |            |

|Program Security Registers|42h    | A23CA16   |  A15CA8   |  A7CA0    |  D7-D0     | D7-D0      |

|Read Security Registers |  48h    | A23CA16   |  A15CA8   |  A7CA0    |  dummy     | (D7-0)     |

--------------------------------------------------------------------------------------

******************************************************************************/

#ifndef _W25QXX_H_

#define _W25QXX_H_

/******************************************************************************

********************************* ļò ********************************

******************************************************************************/

#include "stm32f10x.h"

#include "stm32f10x_gpio.h"

#include "stm32f10x_rcc.h"

#include "stm32f10x_spi.h"

#include "stm32f10x_dma.h"

 

#include <string.h>

#include <stdbool.h>

#include <stdint.h>

/******************************************************************************

******************************* ϵ ͳ    ******************************

******************************************************************************/

/*---------------------* 

*      ö

*----------------------*/

#define W25X_PAGE_SIZE      256         /* ҳС          */

#define W25X_PAGE_NUM       32768       /* ҳĸ        */

#define W25X_SECTOR_SIZE    4096        /* ÿĴС        */    

#define W25X_PAGES_PS       (W25X_SECTOR_SIZE/W25X_PAGE_SIZE)  /* ÿҳ */

 

#define W25X_BUFF_NUM       2           /* SRAMл  */

#define W25X_DUMMY_BYTE     0xFF        /* նֽڶ        */


/******************************************************************************

********************************** Զ ***********************************

****************************** áŶ  ****************************

******************************************************************************/

/*---------------------*

*     ָ

*----------------------*/

#define W25X_ReadStatusReg      0x05    //״̬Ĵ1

#define W25X_ReadStatusReg2     0x35    //״̬Ĵ2

#define W25X_WriteStatusReg     0x01    //д״̬Ĵ1

#define W25X_ReadUniqueID       0x4B    //ȡΨһID

 

#define W25X_WriteEnable        0x06    //дʹ

#define W25X_WriteDisable       0x04    //дر

 

#define W25X_ReadData           0x03    //

#define W25X_PageProgram        0x02    //дFLASH

 

#define W25X_ChipErase          0x60    //ҲΪ0x60

#define W25X_SectorErase        0x20    //4KB        

 

 

#define W25X_PowerDown          0xB9    //,͹

#define W25X_ReleasePowerDown   0xAB    //ָϵ

 

/******************************************************************************

********************************* 궨 *********************************

******************************************************************************/

/*---------------------* 

*       

*----------------------*/

#define W25X_CS_L()          (GPIOA->BRR  = GPIO_Pin_4)

#define W25X_CS_H()          (GPIOA->BSRR = GPIO_Pin_4)

/******************************************************************************

*********************************     *********************************

******************************************************************************/

/*---------------------* 

*      

*----------------------*/

extern uint8_t W25X_Buffer[W25X_SECTOR_SIZE];

/******************************************************************************

*********************************     *********************************

******************************************************************************/

/*---------------------* 

*    

*----------------------*/

extern void W25X_Init(void);                //ʼSPI

extern uint8_t W25X_ReadSR(void);           //ȡ״̬Ĵ

extern uint16_t W25X_ReadID(void);          //ȡID

extern void W25X_Wait_Busy(void);           //ȴW25Xֱ

extern bool W25X_Read_BusyState(void);      //ȡW25Xæ״̬(ȴ)

extern void SPI_Flash_PowerDown(void);      //

extern void SPI_Flash_WakeUp(void);         //

extern void W25X_Erase_Chip(bool bwait);    //ȫƬ,Ҫȴд,Ҫ21

extern void W25X_Erase_Sector(uint32_t Dst_Addr,bool bwait);    //,ʵҪ65ms

extern void W25X_Read_Data(uint8_t * pBuffer,uint32_t ReadAddr,uint16_t NumByteToRead);     //250usִ

extern void W25X_Read_Page(uint8_t * pBuffer,uint32_t PageAddr);    //һҳ,300us

extern void W25X_Write_Page(uint8_t * pBuffer,uint32_t PageAddr);   //дһҳ,Ȳ,Щȴ,600us

extern void W25X_Read_UID(uint8_t * pBuffer);   //ȡW25XΨһMAC,<5us

extern void W25X_Outside(void);    //W25Xⲿ¼ƣƬ

/******************************************************************************

***********************************   END  ************************************

******************************************************************************/

#endif
